@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.74'; # Will we ever get to 1.0!!!
+our $VERSION = '0.75'; # Closer now... 
 
 # Preloaded methods go here.
 
@@ -79,7 +79,7 @@ reports, news, updates, work in progress, lots of stuff.</p>
     tarballs in the file download area of that repository</p>
 
 <p>You can also get help from the <a
-href='https://sourceforge.net/forum/forum.php?forum_id=107255'>project
+href='https://sourceforge.net/projects/opeal/forums/forum/107255'>project
 forum</a> (where I usually hang around) or from <a
 href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing
 list</a> (information at <a
@@ -100,7 +100,7 @@ research, I would be very grateful if you quoted papers such as these
 
 =end html
 
-@article {springerlink:10.1007/s00500-009-0504-3,
+ @article {springerlink:10.1007/s00500-009-0504-3,
    author = {Merelo Guervs, Juan and Castillo, Pedro and Alba, Enrique},
    affiliation = {Universidad de Granada Depto. Arquitectura y Tecnologa de Computadores, ETS Ingenieras Informtica y Telecomunicaciones Granada Spain},
    title = {Algorithm::Evolutionary, a flexible Perl module for evolutionary computation},
@@ -114,7 +114,7 @@ research, I would be very grateful if you quoted papers such as these
    url = {http://dx.doi.org/10.1007/s00500-009-0504-3},
    note = {10.1007/s00500-009-0504-3},
    year = {2010}
-}
+ }
 
  @InProceedings{jj:2008:PPSN,
    author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo
@@ -175,10 +175,10 @@ href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
 also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
 and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
 submitted bugs include <a
-href='http://barbacana.net'>jamarier</a> and Mike Gajewski. Bugs, requests and any kind
-of comment are welcome. <a href='http://alexm.org'>Alex Muntada</a>,
+href='http://barbacana.net'>jamarier</a> and Mike Gajewski. <a href='http://alexm.org'>Alex Muntada</a>,
 from the <a href='http://barcelona.pm.org/'>Barcelona Perl
-Mongers</a>, helped me solve a problem with the Makefile.PL.
+Mongers</a>, helped me solve a problem with the Makefile.PL. Bug reports (and patches), requests and any kind 
+of comment are welcome.
 
 =end html
 
@@ -220,6 +220,9 @@ Some other examples are installed: check out L<tide_bitstring.pl>,
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
 evolutionary algorithms with anything else easily.
 
+=item L<Algorithm::MasterMind::Evolutionary> uses this library to find
+the solution to the MasterMind Puzzle.
+
 You might also be interested in one of the other perl GA and
 evolutionary computation modules out there, such as
 L<AI::Genetic::Pro>.
@@ -230,12 +233,12 @@ L<AI::Genetic::Pro>.
 
 =head1 Copyright
   
-  This file is released under the GPL. See the LICENSE file included in this distribution,
-  or go to http://www.fsf.org/licenses/gpl.txt
+This file is released under the GPL. See the LICENSE file included in this distribution,
+or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/09/24 08:39:07 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.11 2010/09/24 08:39:07 jmerelo Exp $ 
+  CVS Info: $Date: 2010/12/07 12:04:51 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.13 2010/12/07 12:04:51 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.11 $
+  $Revision: 3.13 $
 
 =cut
