@@ -50,7 +50,7 @@ iteration of the algorithm to the population it takes as input
 
 package Algorithm::Evolutionary::Op::Easy;
 
-our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp;
 use Clone::Fast qw(clone);
@@ -159,20 +159,23 @@ sub apply ($) {
   for ( my $i = 0; $i < $pringaos; $i ++ ) {
       my @offspring;
       my $selectedOp = $ops[ $opWheel->spin()];
+      croak "Problems with selected operator" if !$selectedOp;
       for ( my $j = 0; $j < $selectedOp->arity(); $j ++ ) {
-	  my $chosen = $popsort[ int ( rand( $originalSize ) )];
-	  push( @offspring, $chosen ); #No need to clone, it's not changed in ops
+	my $chosen = $popsort[ int ( rand( $originalSize ) )];
+	push( @offspring, $chosen ); #No need to clone, it's not changed in ops
       }
+#     p rint "Op ", ref $selectedOp, "\n";
+#      if ( (ref $selectedOp ) =~ /ssover/ ) {
+#	print map( $_->{'_str'}."\n", @offspring );
+#      }
       my $mutante = $selectedOp->apply( @offspring );
+      croak "Error aplying operator" if !$mutante;
+ #     print "Mutante ", $mutante->{'_str'}, "\n";
       push( @popsort, $mutante );
   }
 
   #Return
-  for ( my $i = 0; $i <= $#popsort; $i++ ) {
-#	print $i, "->", $popsort[$i]->asString, "\n";
-      $pop->[$i] = $popsort[$i];
-  }
-
+  @$pop = @popsort;
   
 }
 
@@ -187,10 +190,10 @@ L<Algorithm::Evolutionary::Op::FullAlgorithm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/27 16:20:24 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy.pm,v 3.1 2009/07/27 16:20:24 jmerelo Exp $ 
+  CVS Info: $Date: 2010/01/16 11:32:15 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy.pm,v 3.3 2010/01/16 11:32:15 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 3.3 $
   $Name $
 
 =cut
