@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl 
 
 =head1 NAME
 
@@ -6,12 +6,6 @@ rectangle-coverage.pl - Find the dot maximally covered by (random) rectangles
 
 =head1 SYNOPSIS
 
-You might have to do 
-
-  prompt% cpanm --installdeps . 
-
-first, since that module is not installed by default with L<Algorithm::Evolutionary>. Use C<sudo> if appropriate.
-
   prompt% ./rectangle-coverage.pl <number-of-rectangles> <arena-side> <bits-per-coordinate> <population> <number of generations> <selection rate>
 
 Or
@@ -295,13 +289,13 @@ J. J. Merelo, C<jj (at) merelo.net>
 
 =head1 Copyright
   
-This file is released under the GPL. See the LICENSE file included in this distribution,
-or go to http://www.fsf.org/licenses/gpl.txt
+  This file is released under the GPL. See the LICENSE file included in this distribution,
+  or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/12/08 10:12:37 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/scripts/rectangle-coverage.pl,v 3.5 2012/12/08 10:12:37 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/30 11:25:18 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/scripts/rectangle-coverage.pl,v 3.3 2009/07/30 11:25:18 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.5 $
+  $Revision: 3.3 $
 
 =cut
 
